/**
 * SPDX-FileCopyrightText: Copyright 2023 Open Mobile Platform LLC <community@omp.ru>
 * SPDX-License-Identifier: BSD-3-Clause
 */
#ifndef TEXTURE_CAMERA_BUFFER_H
#define TEXTURE_CAMERA_BUFFER_H

#include <flutter/plugin-interface.h>
#include <streamcamera/streamcamera.h>

#include <QImage>
#include <QtCore>

typedef std::function<void()> CameraErrorHandler;

class TextureCamera : public Aurora::StreamCamera::CameraListener
{
public:
    TextureCamera(TextureRegistrar *plugin, const CameraErrorHandler &onError);

    void onCameraError(const std::string &errorDescription) override;
    void onCameraFrame(std::shared_ptr<Aurora::StreamCamera::GraphicBuffer> buffer) override;
    void onCameraParameterChanged(Aurora::StreamCamera::CameraParameter,
                                  const std::string &value) override;
    
    std::vector<Encodable> GetAvailableCameras();
    std::map<Encodable, Encodable> Register(std::string cameraName);
    std::map<Encodable, Encodable> Unregister();
    std::map<Encodable, Encodable> StartCapture(size_t width, size_t height);
    void StopCapture();
    std::map<Encodable, Encodable> GetState();
    std::string GetImageBase64();

private:
    bool CreateCamera(std::string cameraName);
    void SendError(std::string error);

private:
    TextureRegistrar *m_plugin;
    
    CameraErrorHandler m_onError;
    std::string m_error;

    Aurora::StreamCamera::CameraManager *m_manager;
    std::shared_ptr<Aurora::StreamCamera::Camera> m_camera;

    int64_t m_textureId = 0;
    size_t m_captureWidth = 0;
    size_t m_captureHeight = 0;
    size_t m_viewWidth = 0;
    size_t m_viewHeight = 0;

    TextureVariant *m_variant;
    QImage *m_image;
};

#endif /* TEXTURE_CAMERA_BUFFER_H */
